==> mono_1.1.8.3.orig.tar.gz: mono-1.1.8.3/mcs/class/System.Drawing/System.Drawing.Design/UITypeEditor.cs <==
//
// System.Drawing.Design.UITypeEditor.cs
// 
// Authors:
//  Alan Tam Siu Lung <Tam@SiuLung.com>
//  Andreas Nahr (ClassDevelopment@A-SoftTech.com)
// 
// (C) 2003 Alan Tam Siu Lung <Tam@SiuLung.com>
// (C) 2003 Andreas Nahr
// 

//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
using System;
using System.ComponentModel;
namespace System.Drawing.Design
{
	public class UITypeEditor
	{

		public UITypeEditor()
		{
		}

		public virtual object EditValue (ITypeDescriptorContext context,
			IServiceProvider provider, object value)
		{
			// We already stated that we can't edit ;)
			return value;
		}
		public object EditValue(IServiceProvider provider, object value)
		{
			return EditValue (null, provider, value);
		}
		public virtual UITypeEditorEditStyle GetEditStyle (ITypeDescriptorContext context)
		{
			return UITypeEditorEditStyle.None;
		}
		public UITypeEditorEditStyle GetEditStyle ()
		{
			return GetEditStyle (null);
		}
		public bool GetPaintValueSupported ()
		{
			return GetPaintValueSupported (null);
		}
		public virtual bool GetPaintValueSupported (ITypeDescriptorContext context)
		{
			return false;
		}
		public void PaintValue (object value, Graphics canvas, Rectangle rectangle)
		{
			PaintValue (new PaintValueEventArgs (null, value, canvas, rectangle));
		}
		public virtual void PaintValue (PaintValueEventArgs e)
		{
			// LAMESPEC: Did not find info in the docs if this should do something here.
			// Usually you would expect, that this class gets inherited and this overridden, 
			// but on the other hand the class is not abstract. Could never observe it did paint anything
			return;
		}
	}
}

==> mono_1.1.13.6.orig.tar.gz: mono-1.1.13.6/mcs/class/System.Drawing/System.Drawing.Design/UITypeEditor.cs <==
//
// System.Drawing.Design.UITypeEditor.cs
// 
// Authors:
//  Alan Tam Siu Lung <Tam@SiuLung.com>
//  Andreas Nahr (ClassDevelopment@A-SoftTech.com)
// 
// (C) 2003 Alan Tam Siu Lung <Tam@SiuLung.com>
// (C) 2003 Andreas Nahr
// 

//
// Copyright (C) 2004-2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System.ComponentModel;
using System.Security.Permissions;

namespace System.Drawing.Design
{
	[PermissionSet (SecurityAction.LinkDemand, Unrestricted = true)]
	[PermissionSet (SecurityAction.InheritanceDemand, Unrestricted = true)]
	public class UITypeEditor
	{

		public UITypeEditor()
		{
		}

		public virtual object EditValue (ITypeDescriptorContext context,
			IServiceProvider provider, object value)
		{
			// We already stated that we can't edit ;)
			return value;
		}
		public object EditValue(IServiceProvider provider, object value)
		{
			return EditValue (null, provider, value);
		}
		public virtual UITypeEditorEditStyle GetEditStyle (ITypeDescriptorContext context)
		{
			return UITypeEditorEditStyle.None;
		}
		public UITypeEditorEditStyle GetEditStyle ()
		{
			return GetEditStyle (null);
		}
		public bool GetPaintValueSupported ()
		{
			return GetPaintValueSupported (null);
		}
		public virtual bool GetPaintValueSupported (ITypeDescriptorContext context)
		{
			return false;
		}
#if !TARGET_JVM
		public void PaintValue (object value, Graphics canvas, Rectangle rectangle)
		{
			PaintValue (new PaintValueEventArgs (null, value, canvas, rectangle));
		}
		public virtual void PaintValue (PaintValueEventArgs e)
		{
			// LAMESPEC: Did not find info in the docs if this should do something here.
			// Usually you would expect, that this class gets inherited and this overridden, 
			// but on the other hand the class is not abstract. Could never observe it did paint anything
			return;
		}
#endif
	}
}
